@@ -1,7 +1,8 @@
-/* dhcpd.h */
+/* dhcpc.h */
 #ifndef _DHCPC_H
 #define _DHCPC_H
 
+#include "libbb_udhcp.h"
 
 #define INIT_SELECTING	0
 #define REQUESTING	1
@@ -13,25 +14,16 @@
 #define RELEASED	7
 
 
-/* Paramaters the client should request from the server */
-#define PARM_REQUESTS \
-	DHCP_SUBNET, \
-	DHCP_ROUTER, \
-	DHCP_DNS_SERVER, \
-	DHCP_HOST_NAME, \
-	DHCP_DOMAIN_NAME, \
-	DHCP_BROADCAST
-
-
 struct client_config_t {
 	char foreground;		/* Do not fork */
 	char quit_after_lease;		/* Quit after obtaining lease */
 	char abort_if_no_lease;		/* Abort if no lease */
+	char background_if_no_lease;	/* Fork to background if no lease */
 	char *interface;		/* The name of the interface to use */
 	char *pidfile;			/* Optionally store the process ID */
 	char *script;			/* User script to run at dhcp events */
-	char *clientid;			/* Optional client id to use */
-	char *hostname;			/* Optional hostname to use */
+	unsigned char *clientid;	/* Optional client id to use */
+	unsigned char *hostname;	/* Optional hostname to use */
 	int ifindex;			/* Index number of the interface to use */
 	unsigned char arp[6];		/* Our arp address */
 };
